%
%    This file is part of the INTERACT Toolbox
%    Copyright 2008 Martin Vejmelka
% 
%	 File: estimate_wphdiff_entropy.m
%     Version: 1.0
%	 Date: 14 April 2008
%     License: GPL version 3 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    Computes the mean phase coherence of the phase difference
%    series.
%
% Synopsis:
%
%	mpc = compute_mean_phase_coherence(ph_diff)
%
% Arguments:
%
%   ph_diff: the phase differences, must be a vector. It does not matter
%            if the phase differences are wrapped or not.
%
% Returns:
%
%   mpc: the mean phase coherence
%
%
function mpc = compute_mean_phase_coherence(ph_diff)

	mpc = sqrt(mean(cos(ph_diff)).^2 + mean(sin(ph_diff)).^2);

end

