%
%    This file is part of the INTERACT Toolbox
%    Copyright 2008 Martin Vejmelka
% 
%	 File: heun_sde_solver.m
%     Version: 1.0
%	 Date: 14 April 2008
%     License: GPL version 2 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    Constructs a permutation partition with 3 neighboring
%    points used for comparison.
%
% Arguments:
%
%    func : the handle of the function that is the ODE (@name)
%
%    x0 : the starting conditions
%
%    t : the time instants when the solution is required
%
%    dW: the realization of the Wiener process, matrix of dimensionality x length(t)
%
%
% Returns:
%
%     xt : the integrated time series
%	
%
function xt = heun_sde_solver(func, x0, t, dW)

	x = x0';
	xt = zeros(length(t), length(x0));
	xt(1,:) = x0;
    
	for i=1:length(t)-1
	
		% find the time step
		deltat = (t(i+1) - t(i));
				
		% the standard euler integration step
		xdot = func(t, x) * deltat + sqrt(deltat) * dW(i,:);
		x_prime = x + xdot;
		
		% the predictor step
		xdot_prime = func(t + deltat, x_prime) * deltat + sqrt(deltat) * dW(i,:);
		
		% the corrector step
		x = x + 0.5 * (xdot + xdot_prime);
		
		xt(i+1,:) = x';
	
	end

end
