%
%    This file is part of the INTERACT Toolbox
%    Copyright 2008 Martin Vejmelka
% 
%	 File: extract_hilbert_phase_fft.m
%     Version: 1.0
%	 Date: 14 April 2008
%     License: GPL version 3 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    This function uses the hilbert transform to compute the imaginary
%    part of a real signal and extracts a phase signal as per the analytical
%    function approach of Gabor.  Uses the FFT method to compute the imaginary
%    part in the spectral domain.
%
% Arguments:
%
%    x: the input time series, may be a matrix, each column is one series
%
% Returns:
%
%    ph: a phase signal for each input time series
%
% Examples:
%
%    t = 1:0.1:100;
%    x = sin(t)';
%    ph = extract_fft_hilbert_phase(x);
%    plot(x, '-', ph, '+')
%
%
function ph = extract_hilbert_phase_fft(x)

	ph = angle(hilbert(x));

