%    INTERACT Toolbox
%
%    This file is part of the INTERACT Toolbox
%    Copyright 2008 Martin Vejmelka
% 
%	 File: make_iid_surr.m
%     Version: 1.0
%	 Date: 14 April 2008
%     License: GPL version 3 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    Constructs surrogates by shuffling the samples around randomly.
%    This creates a time series with the same amplitude distribution
%    but with completely destroyed auto-structure.
%
% Arguments:
%
%    x : a matrix of the time series for which IID surrogates should be constructed,
%        each time series is a column
%
%    same_perm : use the same permutation for all time series (default: 0 = no)
%
% Note:
%
%    Surrogates are constructed individually, i.e. each series is randomly
%    permuted by itself.
%
% Returns:
%
%    s : a matrix of the same size as the original, each column contains 
%        one surrogate
%
%
function s = make_iid_surr(x, same_perm)

    % PRE: set defaults
    if(nargin < 2)
        same_perm = 1;
    end

    [N, M] = size(x);    
    s = zeros(size(x));
    
    if(same_perm == 1)
        p = randperm(N);
        s(p,:) = x;
    else
        for i=1:M

            p = randperm(N);
            s(p,i) = x(:,i);

        end
    end
end
