%
%    This file is part of the INTERACT Toolbox
%    Copyright 2008 Martin Vejmelka
% 
%	 File: eqq_partition.m
%     Version: 1.0
%	 Date: 14 April 2008
%     License: GPL version 3 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    Constructs an equiquantal partition of the input time series.
%    The input time series are processed completely independently.
%
% Synopsis:
%
%    p = eqq_partition(x)
%
% Arguments:
%
%    x: a matrix of input time series, each time series is one column.
%
%    bin_count : the number of bins into which the series should be distributed
%
% Returns:
%
%    p: the mapping of samples to bins for each time series [1 .. bin_count]
%
%
function p = eqq_partition(x, bin_count)

	% input size
	[N, M] = size(x);

	% result matrix - bin assignments
	p = zeros(N, M);

	% obtain sort in increasing order for all columns
	[~, ndx] = sort(x);

	% construct bin assignment array 
	bins = floor([1:N]' / (N + 1e-8) * bin_count) + 1;
	
	% assign bins column-wise using reindex assign
	for i=1:M
		p(ndx(:,i),i) = bins;
	end
	
end
