%    INTERACT Toolbox
%
%    This file is part of the INTERACT Toolbox
%    Copyright 2008-2011 Martin Vejmelka
% 
%	 File: lookup_shift_function.m
%    Version: 1.0
%	 Date: 7 June 2011
%    License: GPL version 3 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    This function accepts a string id of a shift function and returns the
%    handle to the function.  Available shift operations are currently:
%
%      * 'shift' - a simple time series shift [phases and raw]
%      * 'raw_diff' - a difference of the ts and its lagged version [raw]
%      * 'phase_diff' - a difference between ts and lagged version,
%                       which imposes phase semantics (i.e. mod 2*pi).
%
% Synopsis:
%
%    shift_func = lookup_shift_function(func_id)
%
%
% Arguments:
%
%    func_id : the shift function identifier
%
% Returns:
%
%    shift_func : a shift function
%
% Examples:
%
%
function shift_func = lookup_shift_function(func_id)

	func_table = { 'shift', @shift_op;
                   'raw_diff', @raw_diff_op;
                   'phase_diff', @phase_diff_op };
               
    idx = find(cellfun( @(x) strcmp(func_id, x), func_table(:, 1)), 1);
    
    if(isempty(idx))
        error('The shift function %s is not available.', func_id);
    end
    
    shift_func = func_table{idx, 2};
    
    
