%
%    This file is part of the INTERACT Toolbox
%    Copyright 2008 Martin Vejmelka
% 
%	 File: normalize_series.m
%    Version: 1.0;
%	 Date: 14 April 2008
%    License: GPL version 3 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    This function removes the mean of the series and divides it by
%    its standard deviation.
%
% Synopsis:
%
%    y = normalize_series(x)
%
% Arguments:
%
%    x : the input time series, may be a matrix, each column is one series
%
% Returns:
%
%    y : the normalized series
%
% 
function y = normalize_series(x)

	% copy
	y = x;
	
	% compute & remove mean
	m = mean(x);
	for i=1:size(x,2), y(:,i) = y(:,i) - m(i); end

	% normalize by standard deviation
	s = std(x);
    s(s == 0) = 1;
	for i=1:size(x,2), y(:,i) = y(:,i) / s(i); end
