%    INTERACT Toolbox
% 
%	 File: perm_partition3.m
%    Version: 1.0
%	 Date: 14 April 2008
%    License: GPL version 2 or later
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%	Constructs a permutation partition with 3 neighboring
%   points used for comparison.  Reference implementation,
%	for testing purposes only, do not use in actual code.
%
% Arguments:
%
%   x: matrix of input time series, each time series is a column
%
% Returns:
%
%   p: the bins (1-6) computed from the assignment of the permutation method
%	
% Examples:
%
%	None.
%
function p = perm_partition3(s)

	% N - length of each series, M - number of series
	[N, M] = size(s);

	% partitions
	p = zeros(N-2, M);

	% for each time series
	for i=1:M

		% bin is assigned to each sample based on its value and the value
		% of two subsequent samples
		for j=1:N-2
		
			% 1 < 2
			if(s(j,i) < s(j+1,i))

				if(s(j+1,i) < s(j+2,i))
					p(j,i) = 6;
				elseif(s(j,i) < s(j+2,i))
					p(j,i) = 5;
				else
					p(j,i) = 4;
				end

			% 1 > 2
			else

				if(s(j+1,i) > s(j+2,i))
					p(j,i) = 1;
				elseif(s(j,i) > s(j+2,i))
					p(j,i) = 2;
				else
					p(j,i) = 3;
				end

			end

		end

	end
