%    INTERACT Toolbox
% 
%	 File: perm_partition3_v2.m
%    Version: 1.0
%	 Date: 18 May 2011
%    License: GPL version 2 or later
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%	Constructs a permutation partition with 3 neighboring
%   points used for comparison.  More optimized than the
%	reference version.
%
% Synopsis:
%
%	p = perm_partition3_v2(x)
%
% Arguments:
%
%   x: matrix of input time series, each time series is a column
%
% Returns:
%
%   p: the bins (1-6) computed from the assignment of the permutation method
%	
%
% Examples:
%
%	None.
%
function p = perm_partition3_v2(s)

	% N - length of each series, M - number of series
	[N, M] = size(s);

	% partitions
	p = zeros(N-2, M);

	% for each time series
	for i=1:M

		% compute differences
		d1 = (s(2:end,i) > s(1:end-1,i));
		d2 = (s(3:end,i) > s(1:end-2,i)) + 1;

		% assign bins: 6 bins noncontiguous 134568
		p(:,i) = d1(1:end-1) * 4 + d1(2:end) * 2 + d2;
		
		% remove gap at bin 2: bins now 123457
		p(:,i) = p(:,i) - (p(:,i) > 2);

		% remove gap at 6: bins now 123456
		p(:,i) = p(:,i) - (p(:,i) == 7);

	end
