%
%    This file is part of the INTERACT Toolbox
%    Copyright 2008 Martin Vejmelka
% 
%	 File: shannon_entropy.m
%     Version: 1.0
%	 Date: 14 April 2008
%     License: GPL version 3 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    Computes the discrete Shannon entropy given probabilities of
%    of occurrences of each discrete bin in the sample.  This file is
%    vectorized to process multiple time series simultaneously (the bin
%    probabilities for each time series are in one column).
%
%
% Arguments:
%
%    probs : the probabilities of occurrence of each bin, each column
%    contains probabilities for one time series
%
%
% Returns:
%
%   ent : the estimated entropy value (row vector, one for each ts)
%
%
function ent = shannon_entropy(probs)

	% exclude zeros to ensure result is not NaN
	pos_entries = probs > 0;
    
    % compute logs of all entries, avoiding zero entries
    logs = zeros(size(probs));
    logs(pos_entries) = log(probs(pos_entries));

	% compute the standard shannon entropy, no bias correction
	ent = -sum( probs .* logs );

end
