%    INTERACT Toolbox
%
%    This file is part of the INTERACT Toolbox
%    Copyright 2011 Martin Vejmelka
% 
%	 File: shift_op.m
%    Version: 1.0
%	 Date: 14 April 2008
%    License: GPL version 3 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    This function computes the phase difference between a series and
%    its lagged version.  Negative phase differences are shifted by 2pi
%    to positive.  The function requires that the phases are wrapped on 
%    input otherwise the result will be nonsensical.
%
%
% Synopsis:
%
%    shifted = shift_op(ts, win_size, lag)
%
%
% Arguments:
%
%    ts : the time series, may be a matrix, one colum per series
%
%    win_size : the window size
%
%    lag : the number of samples the series will be lagged to compute the phase
%          differences
%
% Returns:
%
%    shifted : a phase difference time series for each input time series
%
% Examples:
%
%   t = 1:0.1:100;
%   x = sin(t)';
%   phd = shift_op(x, 8192, 1)
%
%
function shifted = shift_op(ts, win_size, lag)

	% compute the raw difference
	shifted = ts(lag + 1:win_size + lag, :);
